All of lore.kernel.org
 help / color / mirror / Atom feed
* [U-Boot] [PATCH 1/3] PPC: Fix fsl_upm.c by renaming nand handling functions
@ 2011-10-03 22:56 Marek Vasut
  2011-10-03 22:56 ` [U-Boot] [PATCH 2/3] cmd_sf: Init "skipped" to avoid GCC warning Marek Vasut
                   ` (2 more replies)
  0 siblings, 3 replies; 7+ messages in thread
From: Marek Vasut @ 2011-10-03 22:56 UTC (permalink / raw)
  To: u-boot

This avoids colision with nand subsystem's functions.

Signed-off-by: Marek Vasut <marek.vasut@gmail.com>
Cc: Scott Wood <scottwood@freescale.com>
---
 drivers/mtd/nand/fsl_upm.c |   16 ++++++++--------
 1 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/drivers/mtd/nand/fsl_upm.c b/drivers/mtd/nand/fsl_upm.c
index c33e278..31c174b 100644
--- a/drivers/mtd/nand/fsl_upm.c
+++ b/drivers/mtd/nand/fsl_upm.c
@@ -124,14 +124,14 @@ static void fun_cmd_ctrl(struct mtd_info *mtd, int cmd, unsigned int ctrl)
 		fun_wait(fun);
 }
 
-static u8 nand_read_byte(struct mtd_info *mtd)
+static u8 upm_nand_read_byte(struct mtd_info *mtd)
 {
 	struct nand_chip *chip = mtd->priv;
 
 	return in_8(chip->IO_ADDR_R);
 }
 
-static void nand_write_buf(struct mtd_info *mtd, const u_char *buf, int len)
+static void upm_nand_write_buf(struct mtd_info *mtd, const u_char *buf, int len)
 {
 	int i;
 	struct nand_chip *chip = mtd->priv;
@@ -147,7 +147,7 @@ static void nand_write_buf(struct mtd_info *mtd, const u_char *buf, int len)
 		fun_wait(fun);
 }
 
-static void nand_read_buf(struct mtd_info *mtd, u_char *buf, int len)
+static void upm_nand_read_buf(struct mtd_info *mtd, u_char *buf, int len)
 {
 	int i;
 	struct nand_chip *chip = mtd->priv;
@@ -156,7 +156,7 @@ static void nand_read_buf(struct mtd_info *mtd, u_char *buf, int len)
 		buf[i] = in_8(chip->IO_ADDR_R);
 }
 
-static int nand_verify_buf(struct mtd_info *mtd, const u_char *buf, int len)
+static int upm_nand_verify_buf(struct mtd_info *mtd, const u_char *buf, int len)
 {
 	int i;
 	struct nand_chip *chip = mtd->priv;
@@ -191,10 +191,10 @@ int fsl_upm_nand_init(struct nand_chip *chip, struct fsl_upm_nand *fun)
 #if CONFIG_SYS_NAND_MAX_CHIPS > 1
 	chip->select_chip = fun_select_chip;
 #endif
-	chip->read_byte = nand_read_byte;
-	chip->read_buf = nand_read_buf;
-	chip->write_buf = nand_write_buf;
-	chip->verify_buf = nand_verify_buf;
+	chip->read_byte = upm_nand_read_byte;
+	chip->read_buf = upm_nand_read_buf;
+	chip->write_buf = upm_nand_write_buf;
+	chip->verify_buf = upm_nand_verify_buf;
 	if (fun->dev_ready)
 		chip->dev_ready = nand_dev_ready;
 
-- 
1.7.6.2

^ permalink raw reply related	[flat|nested] 7+ messages in thread

* [U-Boot] [PATCH 2/3] cmd_sf: Init "skipped" to avoid GCC warning
  2011-10-03 22:56 [U-Boot] [PATCH 1/3] PPC: Fix fsl_upm.c by renaming nand handling functions Marek Vasut
@ 2011-10-03 22:56 ` Marek Vasut
  2011-10-03 22:58   ` Mike Frysinger
  2011-10-03 22:56 ` [U-Boot] [PATCH 3/3] PPC: Fix socrates NAND problem Marek Vasut
  2011-10-03 23:46 ` [U-Boot] [PATCH 1/3] PPC: Fix fsl_upm.c by renaming nand handling functions Scott Wood
  2 siblings, 1 reply; 7+ messages in thread
From: Marek Vasut @ 2011-10-03 22:56 UTC (permalink / raw)
  To: u-boot

Signed-off-by: Marek Vasut <marek.vasut@gmail.com>
Cc: Mike Frysinger <vapier@gentoo.org>
---
 common/cmd_sf.c |    2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)

diff --git a/common/cmd_sf.c b/common/cmd_sf.c
index c8c547a..73006c5 100644
--- a/common/cmd_sf.c
+++ b/common/cmd_sf.c
@@ -161,7 +161,7 @@ static int spi_flash_update(struct spi_flash *flash, u32 offset,
 	char *cmp_buf;
 	const char *end = buf + len;
 	size_t todo;		/* number of bytes to do in this pass */
-	size_t skipped;		/* statistics */
+	size_t skipped = 0;	/* statistics */
 
 	cmp_buf = malloc(flash->sector_size);
 	if (cmp_buf) {
-- 
1.7.6.2

^ permalink raw reply related	[flat|nested] 7+ messages in thread

* [U-Boot] [PATCH 3/3] PPC: Fix socrates NAND problem
  2011-10-03 22:56 [U-Boot] [PATCH 1/3] PPC: Fix fsl_upm.c by renaming nand handling functions Marek Vasut
  2011-10-03 22:56 ` [U-Boot] [PATCH 2/3] cmd_sf: Init "skipped" to avoid GCC warning Marek Vasut
@ 2011-10-03 22:56 ` Marek Vasut
  2011-10-03 23:46   ` Scott Wood
  2011-10-03 23:46 ` [U-Boot] [PATCH 1/3] PPC: Fix fsl_upm.c by renaming nand handling functions Scott Wood
  2 siblings, 1 reply; 7+ messages in thread
From: Marek Vasut @ 2011-10-03 22:56 UTC (permalink / raw)
  To: u-boot

nand.c:36: error: static declaration of 'nand_read_buf' follows non-static declaration
/home/marex/u-boot/include/nand.h:139: error: previous declaration of 'nand_read_buf' was here

Signed-off-by: Marek Vasut <marek.vasut@gmail.com>
Cc: Scott Wood <scottwood@freescale.com>
---
 board/socrates/nand.c |   70 ++++++++++++++++++++++++------------------------
 1 files changed, 35 insertions(+), 35 deletions(-)

diff --git a/board/socrates/nand.c b/board/socrates/nand.c
index 7d76f42..823fe80 100644
--- a/board/socrates/nand.c
+++ b/board/socrates/nand.c
@@ -29,13 +29,13 @@
 #include <asm/io.h>
 
 static int state;
-static void nand_write_byte(struct mtd_info *mtd, u_char byte);
-static void nand_write_buf(struct mtd_info *mtd, const u_char *buf, int len);
-static u_char nand_read_byte(struct mtd_info *mtd);
-static u16 nand_read_word(struct mtd_info *mtd);
-static void nand_read_buf(struct mtd_info *mtd, u_char *buf, int len);
-static int nand_verify_buf(struct mtd_info *mtd, const u_char *buf, int len);
-static int nand_device_ready(struct mtd_info *mtdinfo);
+static void sc_nand_write_byte(struct mtd_info *mtd, u_char byte);
+static void sc_nand_write_buf(struct mtd_info *mtd, const u_char *buf, int len);
+static u_char sc_nand_read_byte(struct mtd_info *mtd);
+static u16 sc_nand_read_word(struct mtd_info *mtd);
+static void sc_nand_read_buf(struct mtd_info *mtd, u_char *buf, int len);
+static int sc_nand_verify_buf(struct mtd_info *mtd, const u_char *buf, int len);
+static int sc_nand_device_ready(struct mtd_info *mtdinfo);
 
 #define FPGA_NAND_CMD_MASK		(0x7 << 28)
 #define FPGA_NAND_CMD_COMMAND		(0x0 << 28)
@@ -47,22 +47,22 @@ static int nand_device_ready(struct mtd_info *mtdinfo);
 #define FPGA_NAND_DATA_SHIFT		16
 
 /**
  * nand_write_byte -  write one byte to the chip
  * @mtd:	MTD device structure
  * @byte:	pointer to data byte to write
  */
-static void nand_write_byte(struct mtd_info *mtd, u_char byte)
+static void sc_nand_write_byte(struct mtd_info *mtd, u_char byte)
 {
-	nand_write_buf(mtd, (const uchar *)&byte, sizeof(byte));
+	sc_nand_write_buf(mtd, (const uchar *)&byte, sizeof(byte));
 }
 
 /**
  * nand_write_buf -  write buffer to chip
  * @mtd:	MTD device structure
  * @buf:	data buffer
  * @len:	number of bytes to write
  */
-static void nand_write_buf(struct mtd_info *mtd, const u_char *buf, int len)
+static void sc_nand_write_buf(struct mtd_info *mtd, const u_char *buf, int len)
 {
 	int i;
 	struct nand_chip *this = mtd->priv;
@@ -75,34 +75,34 @@ static void nand_write_buf(struct mtd_info *mtd, const u_char *buf, int len)
 
 
 /**
  * nand_read_byte -  read one byte from the chip
  * @mtd:	MTD device structure
  */
-static u_char nand_read_byte(struct mtd_info *mtd)
+static u_char sc_nand_read_byte(struct mtd_info *mtd)
 {
 	u8 byte;
-	nand_read_buf(mtd, (uchar *)&byte, sizeof(byte));
+	sc_nand_read_buf(mtd, (uchar *)&byte, sizeof(byte));
 	return byte;
 }
 
 /**
  * nand_read_word -  read one word from the chip
  * @mtd:	MTD device structure
  */
-static u16 nand_read_word(struct mtd_info *mtd)
+static u16 sc_nand_read_word(struct mtd_info *mtd)
 {
 	u16 word;
-	nand_read_buf(mtd, (uchar *)&word, sizeof(word));
+	sc_nand_read_buf(mtd, (uchar *)&word, sizeof(word));
 	return word;
 }
 
 /**
  * nand_read_buf -  read chip data into buffer
  * @mtd:	MTD device structure
  * @buf:	buffer to store date
  * @len:	number of bytes to read
  */
-static void nand_read_buf(struct mtd_info *mtd, u_char *buf, int len)
+static void sc_nand_read_buf(struct mtd_info *mtd, u_char *buf, int len)
 {
 	int i;
 	struct nand_chip *this = mtd->priv;
@@ -117,27 +117,27 @@ static void nand_read_buf(struct mtd_info *mtd, u_char *buf, int len)
 }
 
 /**
  * nand_verify_buf -  Verify chip data against buffer
  * @mtd:	MTD device structure
  * @buf:	buffer containing the data to compare
  * @len:	number of bytes to compare
  */
-static int nand_verify_buf(struct mtd_info *mtd, const u_char *buf, int len)
+static int sc_nand_verify_buf(struct mtd_info *mtd, const u_char *buf, int len)
 {
 	int i;
 
 	for (i = 0; i < len; i++) {
-		if (buf[i] != nand_read_byte(mtd));
+		if (buf[i] != sc_nand_read_byte(mtd));
 			return -EFAULT;
 	}
 	return 0;
 }
 
 /**
  * nand_device_ready - Check the NAND device is ready for next command.
  * @mtd:	MTD device structure
  */
-static int nand_device_ready(struct mtd_info *mtdinfo)
+static int sc_nand_device_ready(struct mtd_info *mtdinfo)
 {
 	struct nand_chip *this = mtdinfo->priv;
 
@@ -147,11 +147,11 @@ static int nand_device_ready(struct mtd_info *mtdinfo)
 }
 
 /**
  * nand_hwcontrol - NAND control functions wrapper.
  * @mtd:	MTD device structure
  * @cmd:	Command
  */
-static void nand_hwcontrol(struct mtd_info *mtdinfo, int cmd, unsigned int ctrl)
+static void sc_nand_hwcontrol(struct mtd_info *mtdinfo, int cmd, unsigned int ctrl)
 {
 	if (ctrl & NAND_CTRL_CHANGE) {
 		state &= ~(FPGA_NAND_CMD_MASK | FPGA_NAND_ENABLE);
@@ -178,19 +178,19 @@ static void nand_hwcontrol(struct mtd_info *mtdinfo, int cmd, unsigned int ctrl)
 	}
 
 	if (cmd != NAND_CMD_NONE)
-		nand_write_byte(mtdinfo, cmd);
+		sc_nand_write_byte(mtdinfo, cmd);
 }
 
 int board_nand_init(struct nand_chip *nand)
 {
-	nand->cmd_ctrl = nand_hwcontrol;
+	nand->cmd_ctrl = sc_nand_hwcontrol;
 	nand->ecc.mode = NAND_ECC_SOFT;
-	nand->dev_ready = nand_device_ready;
-	nand->read_byte = nand_read_byte;
-	nand->read_word = nand_read_word;
-	nand->write_buf = nand_write_buf;
-	nand->read_buf = nand_read_buf;
-	nand->verify_buf = nand_verify_buf;
+	nand->dev_ready = sc_nand_device_ready;
+	nand->read_byte = sc_nand_read_byte;
+	nand->read_word = sc_nand_read_word;
+	nand->write_buf = sc_nand_write_buf;
+	nand->read_buf = sc_nand_read_buf;
+	nand->verify_buf = sc_nand_verify_buf;
 
 	return 0;
 }
@@ -47,22 +47,22 @@ static int nand_device_ready(struct mtd_info *mtdinfo);
 
 /**
- * nand_write_byte -  write one byte to the chip
+ * sc_nand_write_byte -  write one byte to the chip
  * @mtd:	MTD device structure
  * @byte:	pointer to data byte to write
@@ -47,22 +47,22 @@ static int nand_device_ready(struct mtd_info *mtdinfo);
 
 /**
- * nand_write_buf -  write buffer to chip
+ * sc_nand_write_buf -  write buffer to chip
  * @mtd:	MTD device structure
  * @buf:	data buffer
@@ -75,34 +75,34 @@ static void nand_write_buf(struct mtd_info *mtd, const u_char *buf, int len)
 
 /**
- * nand_read_byte -  read one byte from the chip
+ * sc_nand_read_byte -  read one byte from the chip
  * @mtd:	MTD device structure
  */
@@ -75,34 +75,34 @@ static void nand_write_buf(struct mtd_info *mtd, const u_char *buf, int len)
 
 /**
- * nand_read_word -  read one word from the chip
+ * sc_nand_read_word -  read one word from the chip
  * @mtd:	MTD device structure
  */
@@ -75,34 +75,34 @@ static void nand_write_buf(struct mtd_info *mtd, const u_char *buf, int len)
 
 /**
- * nand_read_buf -  read chip data into buffer
+ * sc_nand_read_buf -  read chip data into buffer
  * @mtd:	MTD device structure
  * @buf:	buffer to store date
@@ -117,27 +117,27 @@ static void nand_read_buf(struct mtd_info *mtd, u_char *buf, int len)
 
 /**
- * nand_verify_buf -  Verify chip data against buffer
+ * sc_nand_verify_buf -  Verify chip data against buffer
  * @mtd:	MTD device structure
  * @buf:	buffer containing the data to compare
@@ -117,27 +117,27 @@ static void nand_read_buf(struct mtd_info *mtd, u_char *buf, int len)
 
 /**
- * nand_device_ready - Check the NAND device is ready for next command.
+ * sc_nand_device_ready - Check the NAND device is ready for next command.
  * @mtd:	MTD device structure
  */
@@ -147,11 +147,11 @@ static int nand_device_ready(struct mtd_info *mtdinfo)
 
 /**
- * nand_hwcontrol - NAND control functions wrapper.
+ * sc_nand_hwcontrol - NAND control functions wrapper.
  * @mtd:	MTD device structure
  * @cmd:	Command
-- 
1.7.6.2

^ permalink raw reply related	[flat|nested] 7+ messages in thread

* [U-Boot] [PATCH 2/3] cmd_sf: Init "skipped" to avoid GCC warning
  2011-10-03 22:56 ` [U-Boot] [PATCH 2/3] cmd_sf: Init "skipped" to avoid GCC warning Marek Vasut
@ 2011-10-03 22:58   ` Mike Frysinger
  2011-10-04 12:08     ` Marek Vasut
  0 siblings, 1 reply; 7+ messages in thread
From: Mike Frysinger @ 2011-10-03 22:58 UTC (permalink / raw)
  To: u-boot

yeah, Kumar posted a (more complete) fix already
-mike
-------------- next part --------------
A non-text attachment was scrubbed...
Name: not available
Type: application/pgp-signature
Size: 836 bytes
Desc: This is a digitally signed message part.
Url : http://lists.denx.de/pipermail/u-boot/attachments/20111003/5c0a195c/attachment.pgp 

^ permalink raw reply	[flat|nested] 7+ messages in thread

* [U-Boot] [PATCH 1/3] PPC: Fix fsl_upm.c by renaming nand handling functions
  2011-10-03 22:56 [U-Boot] [PATCH 1/3] PPC: Fix fsl_upm.c by renaming nand handling functions Marek Vasut
  2011-10-03 22:56 ` [U-Boot] [PATCH 2/3] cmd_sf: Init "skipped" to avoid GCC warning Marek Vasut
  2011-10-03 22:56 ` [U-Boot] [PATCH 3/3] PPC: Fix socrates NAND problem Marek Vasut
@ 2011-10-03 23:46 ` Scott Wood
  2 siblings, 0 replies; 7+ messages in thread
From: Scott Wood @ 2011-10-03 23:46 UTC (permalink / raw)
  To: u-boot

On Tue, Oct 04, 2011 at 12:56:07AM +0200, Marek Vasut wrote:
> This avoids colision with nand subsystem's functions.
> 
> Signed-off-by: Marek Vasut <marek.vasut@gmail.com>
> Cc: Scott Wood <scottwood@freescale.com>
> ---
>  drivers/mtd/nand/fsl_upm.c |   16 ++++++++--------
>  1 files changed, 8 insertions(+), 8 deletions(-)
> 

Applied to u-boot-nand-flash

-Scott

^ permalink raw reply	[flat|nested] 7+ messages in thread

* [U-Boot] [PATCH 3/3] PPC: Fix socrates NAND problem
  2011-10-03 22:56 ` [U-Boot] [PATCH 3/3] PPC: Fix socrates NAND problem Marek Vasut
@ 2011-10-03 23:46   ` Scott Wood
  0 siblings, 0 replies; 7+ messages in thread
From: Scott Wood @ 2011-10-03 23:46 UTC (permalink / raw)
  To: u-boot

On Tue, Oct 04, 2011 at 12:56:09AM +0200, Marek Vasut wrote:
> nand.c:36: error: static declaration of 'nand_read_buf' follows non-static declaration
> /home/marex/u-boot/include/nand.h:139: error: previous declaration of 'nand_read_buf' was here
> 
> Signed-off-by: Marek Vasut <marek.vasut@gmail.com>
> Cc: Scott Wood <scottwood@freescale.com>
> ---
>  board/socrates/nand.c |   70 ++++++++++++++++++++++++------------------------
>  1 files changed, 35 insertions(+), 35 deletions(-)

Applied to u-boot-nand-flash

-Scott

^ permalink raw reply	[flat|nested] 7+ messages in thread

* [U-Boot] [PATCH 2/3] cmd_sf: Init "skipped" to avoid GCC warning
  2011-10-03 22:58   ` Mike Frysinger
@ 2011-10-04 12:08     ` Marek Vasut
  0 siblings, 0 replies; 7+ messages in thread
From: Marek Vasut @ 2011-10-04 12:08 UTC (permalink / raw)
  To: u-boot

On Tuesday, October 04, 2011 12:58:03 AM Mike Frysinger wrote:
> yeah, Kumar posted a (more complete) fix already
> -mike

Thanks!

Cheers

^ permalink raw reply	[flat|nested] 7+ messages in thread

end of thread, other threads:[~2011-10-04 12:08 UTC | newest]

Thread overview: 7+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2011-10-03 22:56 [U-Boot] [PATCH 1/3] PPC: Fix fsl_upm.c by renaming nand handling functions Marek Vasut
2011-10-03 22:56 ` [U-Boot] [PATCH 2/3] cmd_sf: Init "skipped" to avoid GCC warning Marek Vasut
2011-10-03 22:58   ` Mike Frysinger
2011-10-04 12:08     ` Marek Vasut
2011-10-03 22:56 ` [U-Boot] [PATCH 3/3] PPC: Fix socrates NAND problem Marek Vasut
2011-10-03 23:46   ` Scott Wood
2011-10-03 23:46 ` [U-Boot] [PATCH 1/3] PPC: Fix fsl_upm.c by renaming nand handling functions Scott Wood

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.